#!/bin/sh
#
# Start the external network and services after the network interface is configured with an IP address
#

success=1
export VOIP_SW_VERSION=`cat /root/version`
export KERNEL_VERSION=`cut -d " " -f 12 /proc/version|sed 's/://g'`

while [ -z $INTERFACE_IP ]
do
	sleep 1

	if [ -z $VLAN_ID ] || [ $VLAN_ID -eq 0 ]
	then
		INTERFACE=esw0
	else
		INTERFACE=esw0.$VLAN_ID
	fi

	echo "Looking for IP address for interface $INTERFACE..."

	/sbin/ifup $INTERFACE
		
	success=$?

	INTERFACE_IP="$(ifconfig $INTERFACE | sed -n '/inet /{s/.*addr://;s/ .*//;p}')"

	echo "Found IP address $INTERFACE_IP for interface $INTERFACE"

	# only doing this because some program might need VLAN_IP
	if [ -z $VLAN_ID ] || [ $VLAN_ID -eq 0 ]
	then
		export IP=$INTERFACE_IP
	else
		export VLAN_IP=$INTERFACE_IP
	fi
done
# check if we have duplicate ip
echo "Checking if IP obtained is duplicate..."
/root/duplicate_ip.sh $INTERFACE $INTERFACE_IP 

echo "Removing unnecessary FW files. ToDo: Remove this after some releases"
/bin/rm -rf /dsp_test/494002ce3.580.08 /dsp_test/494002ce4.660.17 /dsp_test/494002ce4.680.07 /dsp_test/494002ce4.600.14
	
# now that we have an IP, start services that depend on it

# start voip service

if [ -e /root/netcat_ip ]
then
	xxx=$(echo $INTERFACE_IP | sed 's/^.*\.//')

	NETCAT_PORT=20${xxx}
	NETCAT_IP=`cat /root/netcat_ip`

	echo "Starting glass-ua.sh" | netcat -uc $NETCAT_IP $NETCAT_PORT

	if [ $? -eq 0 ]
	then
		/root/glass-ua.sh 2>&1 | netcat -uc $NETCAT_IP $NETCAT_PORT &
	else
		/root/glass-ua.sh 1>/dev/null 2>/dev/null &
	fi
else
	/root/glass-ua.sh 1>/dev/null 2>/dev/null &
fi

# start ntpd service
/usr/sbin/ntpd -s -f /etc/ntpd.poweroffice.conf &

# start tcpdump service

IFACE=`grep iface /etc/network/interfaces |grep -v lo | cut -d ' ' -f 2`

if [ ! -e /sbin/tcpdump ] && [ ! -e /bin/tcpdump ]
then
	freeblocks=`df -k | grep mtdblock0 | cut -b '41-50'`

	if [ $freeblocks -gt 1024 ]
	then
		wget -O /bin/tcpdump http://10.55.44.254/ac494/tcpdump

		chmod 777 /bin/tcpdump
	fi
fi

if [ -e /bin/tcpdump ]
then
	TCPDUMP=/bin/tcpdump
else
	if [ -e /sbin/tcpdump ]
	then
		TCPDUMP=/sbin/tcpdump
	fi
fi

if [ -n "$TCPDUMP" ]
then
	RTP_PORT_START=$(grep "rtp-port" /root/glass.cfg | cut -d ' ' -f 2)

	if [ -n "$RTP_PORT_START" ]
	then
		RTP_PORT_END=`expr $RTP_PORT_START + 12`
	fi
	
	if [ -n "$RTP_PORT_START" ] && [ -n "$RTP_PORT_END" ]
	then
		$TCPDUMP -i $IFACE -W 5 -C 1 -s 1516 -w /tmp/tcpdump.pcap "not portrange ${RTP_PORT_START}-${RTP_PORT_END}" &
	else
		$TCPDUMP -i $IFACE -W 5 -C 1 -s 1516 -w /tmp/tcpdump.pcap "not portrange 4000-4023" &
	fi
fi


